#!/usr/bin/env node

'use strict';
const URL = require('url');
const logger = require('../util/logger');
const util = require('../util');
const commander = require('commander');
const opn = require('opn');
const QRCode = require('qrcode');
const base64Img = require('base64-img');
const termImg = require('term-img-x');
const fs = require('fs');

const program = commander
  .allowUnknownOption() // 是否启动自动报错机制
  .usage('<options> [options]')
  .option('-c, --clearCache', 'clear cache for the url')
  .option('-o, --open', 'open in chrome')
  .option('-s, --size [value]', 'size for width and height')
  .option('-i, --ip', 'ip address of the local for remote access')
  .parse(process.argv);

let args1 = program.args[0] || '';

if (program.ip) {
  const internalIp = require('internal-ip');
  const ipv4 = internalIp.v4.sync();
  const urlObj = URL.parse(args1);
  let targetUrl = '';

  if (urlObj.port) {
    targetUrl = `http://${ipv4}:${urlObj.port}${urlObj.path}`;
  } else {
    targetUrl = `http://${ipv4}${urlObj.path}`;
  }

  args1 = targetUrl;
  // console.log('targetUrl', targetUrl, urlObj);
}

if (program.clearCache) {
  args1 = util.clearCacheUrl(args1);
}

logger.log('二维码的值:', args1);

if (args1) {
  // qrcode.generate(args1, { small: program.small }, function(qrcode) {
  //   logger.success('输出的二维码:');
  //   console.log(qrcode);
  // });

  const defaultSize = 400;
  let width = defaultSize;
  let height = defaultSize;
  try {
    if (program.size) {
      const splits = program.size.split('x');
      width = Number(splits[0]) || defaultSize;
      height = Number(splits[1]) || defaultSize;
    }
  } catch (error) {
    width = defaultSize;
    height = defaultSize;
  }

  // console.log('size', width, height);

  QRCode.toDataURL(
    args1,
    {
      errorCorrectionLevel: 'Q',
      width: width,
      height: height
    },
    function(err, base64) {
      // console.log(base64);
      base64Img.img(base64, '', 'nbi_qrcode', function(err, filePath) {
        // console.log(filePath);
        termImg(filePath, {
          noCheckITermApp: true
        });

        fs.unlink(filePath, function(error) {
          if (error) {
            throw error;
          }
        });
      });
    }
  );

  if (program.open) {
    opn(args1, { app: ['google chrome', '--incognito'], wait: false });
  }
}
